# crypto_checker

A simple crypto price checker using CoinGecko API


# Example


>>> from crypto_checker.checker import CryptoChecker
>>>
>>> cc = CryptoChecker()
>>>
>>> cc.get_price('bitcoin')
>>>
>>
